@@ -20,7 +20,7 @@ def get_quarter_end(date, calendar_type):
 
 def create_dataset(ew_data):
 
-    ew_data = ew_data[(ew_data["Ticker"] != 'All Other (Suppressed)') & (~ew_data["Ticker"].str.contains(".", regex=False))]
+    ew_data = ew_data[(~ew_data["Ticker"].str.contains(" ", regex=False)) & (~ew_data["Ticker"].str.contains(".", regex=False))]
     tickers = list(ew_data["Ticker"].unique())
     bclient = BloombergClient()
     bdata = bclient.get_quarterly_financials(tickers)
@@ -46,7 +46,10 @@ def create_dataset(ew_data):
 
     ew_data = ew_data.groupby(["Ticker","quarter_end","Category"])["Dollars Adjusted"].sum().reset_index()
     ew_data = ew_data.pivot(index=["Ticker","quarter_end"], columns="Category", values="Dollars Adjusted").reset_index()
-    ew_data.index.name = None
+    ew_data = ew_data.rename(columns={"Ticker":"symbol"})
+    
+    all_data = ew_data.merge(bdata, on=["symbol","quarter_end"])
+    return all_data
 
 def run_summary_cat_report(output_dir, df):
 
